=======
Credits
=======

Development Leads
-----------------

- `Greg Tucker <https://github.com/gregtucker>`_
- `Nicole Gasparini <https://github.com/nicgaspar>`_
- `Erkan Istanbulluoglu <https://github.com/erkanistan>`_
- `Daniel Hobley <https://github.com/SiccarPoint>`_
- `Sai S. Nudurupati <https://github.com/saisiddu>`_
- `Jordan Adams <https://github.com/jadams15>`_
- `Eric Hutton <https://github.com/mcflugen>`_
- `Jenny Knuth <https://github.com/jennyknuth>`_
- `Katy Barnhart <https://github.com/kbarnhart>`_
- `Margaux Mouchene <https://github.com/margauxmouchene>`_
- `Christina Bandaragoda <https://github.com/ChristinaB>`_
- `Nathan Lyons <https://github.com/nathanlyons>`_

Contributors
------------

.. credits-roll start-author-list

* `Eric Hutton <https://github.com/mcflugen>`_
* `Katy Barnhart <https://github.com/kbarnhart>`_
* `Dan Hobley <https://github.com/SiccarPoint>`_
* `Greg Tucker <https://github.com/gregtucker>`_
* `Jordan Adams <https://github.com/jadams15>`_
* `Sai Nudurupati <https://github.com/saisiddu>`_
* `Nicole M Gasparini <https://github.com/nicgaspar>`_
* `Charlie Shobe <https://github.com/cmshobe>`_
* `David Litwin <https://github.com/DavidLitwin>`_
* `Sebastien Lenard <https://github.com/sebastien-lenard>`_
* `Ronda Strauch <https://github.com/RondaStrauch>`_
* `Margaux Mouchene <https://github.com/margauxmouchene>`_
* `Jenny Knuth <https://github.com/jennyknuth>`_
* `Benjamin Campforts <https://github.com/BCampforts>`_
* `Nathan Lyons <https://github.com/nathanlyons>`_
* `Jeffrey Keck <https://github.com/keckje>`_
* `Rachel Glade <https://github.com/Glader011235>`_
* `Laurent Roberge <https://github.com/loroberge>`_
* `Giuseppecipolla95 <https://github.com/Giuseppecipolla95>`_
* `Dylan Ward <https://github.com/ddoubleprime>`_
* `Amanda Manaster <https://github.com/amanaster2>`_
* `Allison Pfeiffer <https://github.com/pfeiffea>`_
* `Mark Piper <https://github.com/mdpiper>`_
* `Jay Hariharan <https://github.com/elbeejay>`_
* `Shelby Ahrendt <https://github.com/shelbyahrendt>`_
* `Abby Langston <https://github.com/alangston>`_
* `Andy Wickert <https://github.com/awickert>`_
* `Christopher Sheehan <https://github.com/Sheehace>`_
* `Francis Rengers <https://github.com/frengers>`_
* `Josh Wolpert <https://github.com/josh-wolpert>`_
* `Kristen Thyng <https://github.com/kthyng>`_
* `Muneer Ahammad <https://github.com/muneerVT>`_
* `Sarah Lundell <https://github.com/slundell123>`_
